@@ -25,7 +25,7 @@ impl Kubectl {
                     "resource_version": secret.resource_version(),
                 },
                 "type": r#type,
-                "string-data": string_data,
+                "string_data": string_data,
             }))?;
 
             (secret, true)
@@ -37,7 +37,7 @@ impl Kubectl {
                     "name": name,
                 },
                 "type": r#type,
-                "string-data": string_data
+                "string_data": string_data
             }))?;
 
             (secret, false)
