@@ -65,9 +65,10 @@ impl StateHub {
         };
 
         let cluster_name = kubectl.cluster_name();
+        let namespace = &register_cluster.namespace;
         let cluster = self
             .api
-            .register_cluster(&cluster_name, provider, locations)
+            .register_cluster(&cluster_name, namespace, provider, locations)
             .await
             .map(Quiet)?;
 
